@@ -1,3 +1,5 @@
+# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 from .wiggle import Entity
 from fifo.helper import *
 
@@ -19,6 +21,7 @@ class Network(Entity):
         parser_networks = subparsers.add_parser('networks', help='network related commands')
         parser_networks.set_defaults(endpoint=self)
         subparsers_networks = parser_networks.add_subparsers(help='network commands')
+        self.add_metadata_parser(subparsers_networks)
         parser_networks_list = subparsers_networks.add_parser('list', help='lists networks')
         parser_networks_list.add_argument("--fmt", action=ListAction,
                                           default=['uuid', 'name','ipranges'])
